@@ -4,7 +4,7 @@ from trytond.pool import PoolMeta
 from trytond.model import fields
 from trytond.pyson import Eval
 
-__all__ = ['ProductBom']
+__all__ = ['ProductBom', 'ProductionLeadTime']
 
 
 class ProductBom:
@@ -16,3 +16,14 @@ class ProductBom:
             ('boms', '=', Eval('bom', 0)),
             ],
         depends=['bom'])
+
+
+class ProductionLeadTime:
+    __metaclass__ = PoolMeta
+    __name__ = 'production.lead_time'
+    routing = fields.Many2One('production.routing', 'Routing',
+        ondelete='CASCADE',
+        domain=[
+            ('boms', '=', Eval('bom', 0)),
+            ],
+        depends=['bom'])
